Skip to contents

Local Habitat Suitability Output Extension

See also

Other Local Habitat Output helpers: insertSuitabilityFiles(), suitabilityFile()

Super class

LandisExtension -> OutputLocalHabitat

Active bindings

OutputTimestep

Integer. Output frequency (years); must be >= Timestep.

MapFileNames

Character. Output filename pattern; must contain {HabitatName} and {timestep}.

SuitabilityFiles

List of SuitabilityFile objects, or a character vector of relative filenames (auto-wrapped).

Methods

Inherited methods


OutputLocalHabitat$new()

Usage

OutputLocalHabitat$new(
  path,
  Timestep = 1L,
  OutputTimestep = NULL,
  MapFileNames = NULL,
  SuitabilityFiles = list()
)

Arguments

path

Character. Directory path.

Timestep

Integer. Inner simulation interval (years).

OutputTimestep

Integer. Output frequency (years); must be >= Timestep.

MapFileNames

Character. Output filename pattern; must contain the literals {HabitatName} and {timestep}.

SuitabilityFiles

List of SuitabilityFile sub-objects (see suitabilityFile()) or a character vector of filenames (auto-wrapped).


OutputLocalHabitat$write()

Write extension inputs to disk

Usage

OutputLocalHabitat$write()


OutputLocalHabitat$clone()

The objects of this class are cloneable with this method.

Usage

OutputLocalHabitat$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.