Skip to contents

Wildlife Habitat Output Extension

See also

suitabilityFile() (also used by OutputLocalHabitat).

Other Wildlife Habitat Output helpers: insertSuitabilityFiles(), suitabilityFile()

Super class

LandisExtension -> OutputWildlifeHabitat

Active bindings

OutputTimestep

Integer. Output frequency (years); must be >= Timestep.

MapFileNames

Character. Output filename pattern; must contain {wildlifeName} and {timestep}.

SuitabilityFiles

List of SuitabilityFile objects, or a character vector of relative filenames (auto-wrapped).

Methods

Inherited methods


OutputWildlifeHabitat$new()

Usage

OutputWildlifeHabitat$new(
  path,
  Timestep = 1L,
  OutputTimestep = NULL,
  MapFileNames = NULL,
  SuitabilityFiles = list()
)

Arguments

path

Character. Directory path.

Timestep

Integer. Inner simulation interval (years).

OutputTimestep

Integer. Output frequency (years); must be >= Timestep.

MapFileNames

Character. Output filename pattern; must contain the literals {wildlifeName} and {timestep}.

SuitabilityFiles

List of SuitabilityFile sub-objects (see suitabilityFile()) or a character vector of filenames (auto-wrapped).


OutputWildlifeHabitat$write()

Write extension inputs to disk

Usage

OutputWildlifeHabitat$write()


OutputWildlifeHabitat$clone()

The objects of this class are cloneable with this method.

Usage

OutputWildlifeHabitat$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.