Skip to contents

A character vector naming the eight GCMs that the bcgov ensemble-selection guidance identifies as a defensible subset of the full 13-model ensemble returned by climr::list_gcms(). The subset is more consistent with the IPCC assessment of climate sensitivity than the full ensemble.

Usage

climr_ensemble_8

Value

Character vector of length 8.

Examples

climr_ensemble_8
#> [1] "ACCESS-ESM1-5" "CNRM-ESM2-1"   "EC-Earth3"     "GFDL-ESM4"    
#> [5] "GISS-E2-1-G"   "MIROC6"        "MPI-ESM1-2-HR" "MRI-ESM2-0"