Skip to contents

The ForCS tables are keyed on the species names in species.txt, which for a factorial are pseudo-species. This maps each pseudo-species back to its real species, joins the real species' values, and renames.

Usage

growth_expand_over_pseudo_species(df, design)

Arguments

df

A tibble with a species column of REAL species codes.

design

A design table from growth_calibration_design().

Value

df expanded to one row per pseudo-species, species replaced.