Skip to contents

Create InitialCommunities and InitialCommunitiesMap Files

Usage

prepInitialCommunities(cohortData, pixelGroupMap, path)

Arguments

cohortData

A data.table with columns pixelGroup, speciesCode, age, B, and ecoregionGroup describing cohort composition per pixel group

pixelGroupMap

A SpatRaster identifying the locations of the pixel groups in cohortData

path

Character. Path specifying a directory to use for the scenario runs.

Value

Character string(s) specifying suitable LANDIS-II input file(s), created as a side effect of the function.

See also

Used by succession extensions: BiomassSuccession, DGSSuccession, ForCS, NECNSuccession, and PnETSuccession.