Skip to contents

Writes the PNEToutputsites input file (12 of the user guide), which lists individual sites at which detailed PnET output tables are requested. Two coordinate forms are supported:

Usage

prepPNEToutputsites(
  df = NULL,
  path,
  coords = c("rowcol", "map"),
  filename = "PNEToutputsites.txt"
)

Arguments

df

data.frame whose first column (Site) names each site, with the remaining columns matching coords.

path

Character. Path specifying a directory to use for the scenario runs.

coords

Character, one of "map" or "rowcol". Default "rowcol".

filename

Character, specifying a filename (will be appended to path).

Value

Character string(s) specifying suitable LANDIS-II input file(s), created as a side effect of the function.

Details

  • map coordinates (coords = "map"): four numeric columns MapCoordinatesX, MapCoordinatesY, MapCoordinatesMaxX, MapCoordinatesMaxY.

  • row/column coordinates (coords = "rowcol"): two integer columns Row, Column.