Skip to contents

Writes the disturbance reductions file (10 of the user guide), which specifies how each disturbance partitions biomass into / out of the dead pools. Rows correspond to the five reductions in .pnetDisturbancePools; remaining columns are the disturbance types active in the scenario (e.g. fire, wind, harvest, bda).

Usage

prepPnETDisturbanceReductions(
  df = NULL,
  path,
  filename = "DisturbanceReductions.txt"
)

Arguments

df

data.frame whose first column is Pool (with values in .pnetDisturbancePools) and whose remaining columns are disturbance types. Use defaultPnETDisturbanceReductions() for a starting point. Reduction values must be in [0, 1].

path

Character. Path specifying a directory to use for the scenario runs.

filename

Character, specifying a filename (will be appended to path).

Value

Character string(s) specifying suitable LANDIS-II input file(s), created as a side effect of the function.