Create LANDIS-II scenario files
scenario.RdCreate LANDIS-II scenario files
Usage
scenario(
name = NULL,
extensions = NULL,
climate_config = NULL,
path = NULL,
...,
validate = getOption("landisutils.validate_scenario", TRUE)
)Arguments
- name
Character. Label to use as a filename and label for this scenario.
- extensions
List of LandisExtension objects.
- climate_config
LandisClimateConfig object.
- path
Character. Path specifying a directory to use for the scenario runs.
- ...
Arguments passed to other functions:
CellLengthNumeric. Size of ecoregion raster cells (in $m$);DisturbancesRandomOrderLogical. Should disturbances be applied in a random order?DurationNumeric. Number of years to run the simulation;EcoregionsFilesList of length 2 containing character file paths;RandomNumberSeedInteger. Seed used to initialize the LANDIS-II random number generator;SpeciesInputFileCharacter. Path to input file;
- validate
Logical. Run
validate_landis_scenario()on the assembled directory before returning. Defaults togetOption("landisutils.validate_scenario", TRUE). SetFALSEwhen the referenced input files are deliberately stubs (as in this package's own tests of config-file generation).