Climate BDA (Biological Disturbance Agent) Extension
ClimateBDA.RdClimate BDA (Biological Disturbance Agent) Extension
References
LANDIS-II Biological Disturbance Agent v5 Extension User Guide https://github.com/LANDIS-II-Foundation/Extension-Base-BDA/blob/master/docs/LANDIS-II%20Biological%20Disturbance%20Agent%20v5%20User%20Guide.pdf
See also
Other Climate BDA helpers:
bdaAgent(),
insertAgentHeader(),
insertBDAInputFiles(),
insertBDASpeciesParameters(),
insertDispersal(),
insertDisturbanceModifiers(),
insertEcoregionModifiers(),
insertIgnoredSpecies(),
insertIntensityClasses(),
insertNeighborhood(),
insertOutbreakPattern(),
writeAgentFile()
Super class
LandisExtension -> ClimateBDA
Active bindings
AgentsList of
BDAAgentobjects.MapNamesCharacter. Output map filename pattern; must contain the literal
{agentName}and{timestep}placeholders.SRDMapNames(Optional) Character. SRD output map filename pattern; must contain
{agentName}and{timestep}.NRDMapNames(Optional) Character. NRD output map filename pattern; must contain
{agentName}and{timestep}.BDPMapNames(Optional) Character. BDP output map filename pattern; must contain
{agentName}and{timestep}.LogFileCharacter. Relative file path.
output_filesCharacter vector of output files (relative paths from the scenario directory) that this extension is expected to produce at run time. Subclasses override this to return their extension-specific log files, event CSVs, etc. These paths are collected by
scenario()and written tooutput_manifest.txtsotar_landis()can track them explicitly without relying onlist.files()discovery.Map files whose names depend on the timestep (e.g.
BiomassC-10.tif) are NOT included here; they are discovered bytar_landis()'soutput_dirscan instead.
Methods
Inherited methods
ClimateBDA$new()
Usage
ClimateBDA$new(
path,
Timestep = NULL,
Agents = list(),
MapNames = NULL,
SRDMapNames = NULL,
NRDMapNames = NULL,
BDPMapNames = NULL,
LogFile = "bda/bda-log.csv"
)Arguments
pathCharacter. Directory path.
TimestepInteger.
AgentsList of
BDAAgentobjects (seebdaAgent()).MapNamesCharacter. Output map filename pattern; must contain the literal
{agentName}and{timestep}placeholders.SRDMapNames(Optional) Character. SRD output map filename pattern; must contain the literal
{agentName}and{timestep}placeholders.NRDMapNames(Optional) Character. NRD output map filename pattern; must contain the literal
{agentName}and{timestep}placeholders.BDPMapNames(Optional) Character. BDP output map filename pattern; must contain the literal
{agentName}and{timestep}placeholders.LogFileCharacter. Relative file path for the BDA CSV log.