Skip to contents

Forest Carbon Succession (ForCS) Extension

Super class

LandisExtension -> ForCS

Active bindings

SeedingAlgorithm

Character. Dispersal algorithm to use. One of "WardSeedDispersal", "NoDispersal", "UniversalDispersal".

ForCSClimateFile

Character. Relative file path.

InitialCommunitiesFiles

Character. Relative file paths.

DisturbanceMatrixFile

Character. Relative file path.

SnagFile

(Optional) Character. Relative file path.

OutputTables

data.frame.

ForCSMapControl

data.frame.

MapOutputInterval

Integer.

SpinUp

data.frame.

AvailableLightBiomass

data.frame.

LightEstablishmentTable

data.frame.

SpeciesParameters

data.frame.

DOMPools

data.frame.

EcoSppDOMParameters

data.frame.

ForCSProportions

data.frame.

ANPPTimeSeries

data.frame.

MaxBiomassTimeSeries

data.frame.

EstablishProbabilities

data.frame.

RootDynamics

data.frame.

output_files

Character vector of ForCS-specific log CSV files produced at run time, relative to the scenario directory (root level). These fixed names are written by the ForCS extension regardless of scenario configuration. See LandisExtension for the contract.

Methods

Inherited methods


ForCS$new()

Usage

ForCS$new(
  path,
  Timestep = 1,
  SeedingAlgorithm = NULL,
  ForCSClimateFile = NULL,
  InitialCommunitiesFiles = NULL,
  DisturbanceMatrixFile = NULL,
  SnagFile = NULL,
  OutputTables = NULL,
  ForCSMapControl = NULL,
  MapOutputInterval = NULL,
  SpinUp = NULL,
  AvailableLightBiomass = NULL,
  LightEstablishmentTable = NULL,
  SpeciesParameters = NULL,
  DOMPools = NULL,
  EcoSppDOMParameters = NULL,
  ForCSProportions = NULL,
  ANPPTimeSeries = NULL,
  MaxBiomassTimeSeries = NULL,
  EstablishProbabilities = NULL,
  RootDynamics = NULL
)

Arguments

path

Character. Directory path.

Timestep

Integer.

SeedingAlgorithm

Character. Dispersal algorithm to use. One of "WardSeedDispersal", "NoDispersal", "UniversalDispersal".

ForCSClimateFile

Character. Relative file path. Mean-annual-temperature climate file specific to ForCS (see prepClimateFile()).

InitialCommunitiesFiles

Character. Two-element vector of relative file paths: the initial-communities text/CSV and the initial-communities raster.

DisturbanceMatrixFile

Character. Relative file path.

SnagFile

(Optional) Character. Relative file path. May be NULL.

OutputTables

data.frame corresponding to ForCSOutput (one row, four columns: Biomass, DOM_Pools, Fluxes, Summary intervals).

ForCSMapControl

data.frame (one row, seven columns: BiomassC, SDOMC, NBP, NEP, NPP, RH, ToFPS toggles).

MapOutputInterval

Integer. Map output interval (years).

SpinUp

data.frame (one row, four columns: On/Off Flag, Biomass Spin-up Flag, Tolerance %, Max Iterations).

AvailableLightBiomass

data.frame.

LightEstablishmentTable

data.frame.

SpeciesParameters

data.frame with 10 columns: Species, LeafLong, MortalShape, MerchMinAge, MerchCurveA, MerchCurveB, PropNonMerchToFastAG, GrowthShape, ShadeTolerance, FireTolerance.

DOMPools

data.frame.

EcoSppDOMParameters

data.frame.

ForCSProportions

data.frame.

ANPPTimeSeries

data.frame.

MaxBiomassTimeSeries

data.frame.

EstablishProbabilities

data.frame.

RootDynamics

data.frame.


ForCS$write()

Write extension inputs to disk

Usage

ForCS$write()


ForCS$clone()

The objects of this class are cloneable with this method.

Usage

ForCS$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

## See vignette for example usage