LandisClimateConfig class
LandisClimateConfig.RdKeeps track of the input files created for the climate library
Public fields
pathcharacter specifying the (directory) path to the extension input files
filescharacter specifying the filenames of the extension input files (relative to
path); the principle extension input file should be listed first.