LandisExtension class
LandisExtension.RdKeeps track of the input files created for an extension
Public fields
pathCharacter specifying the (directory) path to the extension input files.
filesCharacter specifying the filenames of the extension input files (relative to
path); the principle extension input file should be listed first.
Active bindings
TimestepInteger.
typecharacter specifying the extension type (must be one of: succession, disturbance, other)
Methods
Method new()
Usage
LandisExtension$new(
name = NULL,
type = NA_character_,
path = NA_character_,
Timestep = 1L
)