Linear Wind Disturbance Extension
LinearWind.RdLinear Wind Disturbance Extension
References
LANDIS-II Linear Wind Disturbance v3 Extension User Guide https://github.com/LANDIS-II-Foundation/Extension-LinearWind/blob/master/docs/LANDIS-II%20Linear%20Wind%20v3%20User%20Guide.pdf
Super class
LandisExtension -> LinearWind
Active bindings
NumEventsMeanNumeric. Mean number of events per 40,000 km^2 per year.
NumEventsStDevNumeric. Standard deviation of number of events.
TornadoLengthLambdaNumeric. Weibull lambda for tornado length (km).
TornadoLengthAlphaNumeric. Weibull alpha for tornado length (km).
TornadoWidthNumeric. Mean width of tornado events (km).
TornadoIntensityTableNumeric vector of 5 percentages (sum 100) for intensity classes
0.2, 0.4, 0.6, 0.8, 1.0.TornadoPropNumeric. Proportion of events that are tornadoes (0-1).
DerechoLengthLambdaNumeric. Weibull lambda for derecho length (km).
DerechoLengthAlphaNumeric. Weibull alpha for derecho length (km).
DerechoWidthNumeric. Mean width of derecho events (km).
DerechoIntensityTableNumeric vector of 5 percentages (sum 100) for intensity classes
0.2, 0.4, 0.6, 0.8, 1.0.PropIntensityVarNumeric. Variability in wind intensity within an event (0-1).
WindDirectionTableNumeric vector of 4 percentages (sum 100) for directions
N-S, NE-SW, E-W, SE-NW.EcoregionModifiersdata.framewith columnsEcoregion,Modifier.WindSeveritiesdata.framewith columnsSeverity,LowerAge,UpperAge,WindspeedMortalityThreshold.IntensityMapNamesCharacter. File pattern for wind intensity output maps; must contain the literal
{timestep}placeholder.SeverityMapNamesCharacter. File pattern for wind severity output maps; must contain the literal
{timestep}placeholder.LogFileCharacter. Relative file path.
output_filesCharacter vector of output files (relative paths from the scenario directory) that this extension is expected to produce at run time. Subclasses override this to return their extension-specific log files, event CSVs, etc. These paths are collected by
scenario()and written tooutput_manifest.txtsotar_landis()can track them explicitly without relying onlist.files()discovery.Map files whose names depend on the timestep (e.g.
BiomassC-10.tif) are NOT included here; they are discovered bytar_landis()'soutput_dirscan instead.
Methods
Inherited methods
LinearWind$new()
Usage
LinearWind$new(
path,
Timestep = NULL,
NumEventsMean = NULL,
NumEventsStDev = NULL,
TornadoLengthLambda = NULL,
TornadoLengthAlpha = NULL,
TornadoWidth = NULL,
TornadoIntensityTable = NULL,
TornadoProp = NULL,
DerechoLengthLambda = NULL,
DerechoLengthAlpha = NULL,
DerechoWidth = NULL,
DerechoIntensityTable = NULL,
PropIntensityVar = NULL,
WindDirectionTable = NULL,
EcoregionModifiers = NULL,
WindSeverities = NULL,
IntensityMapNames = NULL,
SeverityMapNames = NULL,
LogFile = "linearwind/log.csv"
)Arguments
pathCharacter. Directory path.
TimestepInteger. Years.
NumEventsMeanNumeric. Mean number of wind events per 40,000 km^2 per year.
NumEventsStDevNumeric. Standard deviation of number of wind events.
TornadoLengthLambdaNumeric. Weibull lambda for tornado event length (km).
TornadoLengthAlphaNumeric. Weibull alpha for tornado event length (km).
TornadoWidthNumeric. Mean width of tornado events (km).
TornadoIntensityTableNumeric vector of length 5 giving the percentage of tornado events with maximum intensity in each class
0.2, 0.4, 0.6, 0.8, 1.0; must sum to 100.TornadoPropNumeric. Proportion of events that are tornadoes (0-1); the remainder are derechos.
DerechoLengthLambdaNumeric. Weibull lambda for derecho event length (km).
DerechoLengthAlphaNumeric. Weibull alpha for derecho event length (km).
DerechoWidthNumeric. Mean width of derecho events (km).
DerechoIntensityTableNumeric vector of length 5 giving the percentage of derecho events with maximum intensity in each class
0.2, 0.4, 0.6, 0.8, 1.0; must sum to 100.PropIntensityVarNumeric. Variability in wind intensity within an event (0-1).
WindDirectionTableNumeric vector of length 4 giving the percentage of events with primary direction
N-S, NE-SW, E-W, SE-NW; must sum to 100.EcoregionModifiersdata.framewith columnsEcoregion,Modifier(Modifierin[-1, 1]); optional.WindSeveritiesdata.framewith columnsSeverity,LowerAge,UpperAge,WindspeedMortalityThreshold; rows must be ordered by decreasingSeverity. Defaults todefaultLinearWindSeverities().IntensityMapNamesCharacter. File pattern for wind intensity output maps; must contain the literal
{timestep}placeholder.SeverityMapNamesCharacter. File pattern for wind severity output maps; must contain the literal
{timestep}placeholder.LogFileCharacter. Relative file path.