NECN Succession Extension
NECNSuccession.RdNECN Succession Extension
References
LANDIS-II Net Ecosystem CN Succession v8 Extension User Guide https://github.com/LANDIS-II-Foundation/Extension-NECN-Succession/blob/master/docs/LANDIS-II%20Net%20Ecosystem%20CN%20Succession%20v8%20User%20Guide.pdf
See also
Helpers that prepare inputs for this extension:
prepNECNFireReductionParameters().
Shared scenario inputs:
prepClimateConfig(),
prepInitialCommunities(),
prepSpeciesData().
Other NECN Succession helpers:
insertNECNFireReductionParameters(),
insertNECNHarvestReductionParameters(),
prepNECNFireReductionParameters()
Super class
LandisExtension -> NECNSuccession
Active bindings
SeedingAlgorithmCharacter. Dispersal algorithm to use. One of
"WardSeedDispersal","NoDispersal","UniversalDispersal".InitialCommunitiesCSVCharacter. Relative file path.
InitialCommunitiesMapCharacter. Relative file path.
ClimateConfigFileCharacter. Relative file path.
SoilMapsNamed list of relative file paths. Required keys:
SoilDepthMapName,SoilDrainMapName,SoilBaseFlowMapName,SoilStormFlowMapName,SoilFieldCapacityMapName,SoilWiltingPointMapName,SoilPercentSandMapName,SoilPercentClayMapName,InitialSOM1CsurfMapName,InitialSOM1NsurfMapName,InitialSOM1CsoilMapName,InitialSOM1NsoilMapName,InitialSOM2CMapName,InitialSOM2NMapName,InitialSOM3CMapName,InitialSOM3NMapName,InitialDeadWoodSurfaceMapName,InitialDeadCoarseRootsMapName.OptionalClimateMapsNamed list of relative file paths. Allowed keys:
SlopeMapName,AspectMapName,NormalSWAMapName,NormalCWDMapName,NormalTempMapName.CalibrateModeLogical, or character indicating "yes" or "no".
SmokeModelOutputsLogical, or character indicating "yes" or "no".
Write_SWA_MapsLogical, or character indicating "yes" or "no".
Write_CWD_MapsLogical, or character indicating "yes" or "no".
Write_Temperature_MapsLogical, or character indicating "yes" or "no".
Write_Species_Drought_MapsLogical, or character indicating "yes" or "no".
WaterDecayFunctionCharacter. One of
"Linear"or"Ratio".ProbabilityEstablishAdjustNumeric.
InitialMineralNNumeric (g m-2).
InitialFineFuelsNumeric in
[0, 1].AtmosphericNSlopeNumeric.
AtmosphericNInterceptNumeric.
LatitudeNumeric (degrees).
DenitrificationRateNumeric in
[0, 1].DecayRateSurfNumeric in
[0, 1].DecayRateSOM1Numeric in
[0, 1].DecayRateSOM2Numeric in
[0, 1].DecayRateSOM3Numeric in
[0, 1].GrassThresholdMultiplierNumeric.
OutputMapsNamed list. See table 3 of the user guide. Allowed names:
ANPPMapName,ANPPMapFrequency,ANEEMapName,ANEEMapFrequency,SoilCarbonMapName,SoilNitrogenMapName,TotalCMapName.*MapNamevalues are file-name templates and must contain the literal{timestep}placeholder (user guide 2.29) – LANDIS-II replaces it with the simulation year, e.g."NECN/ANPP-{timestep}.tif".CreateInputCommunityMapsLogical, or character indicating "yes" or "no".
VariableOverridesNamed list. Allowed names:
Stormflow,WaterFactor1,WaterFactor2,AnaerobicFactor1,AnaerobicFactor2,AnaerobicFactor3.SpeciesParametersCharacter. Relative file path.
DroughtMortalityParametersCharacter. Relative file path.
FireReductionParametersdata.frame.HarvestReductionParametersdata.frame.
Methods
Inherited methods
NECNSuccession$new()
Usage
NECNSuccession$new(
path,
Timestep = 10L,
SeedingAlgorithm = NULL,
InitialCommunitiesCSV = NULL,
InitialCommunitiesMap = NULL,
ClimateConfigFile = NULL,
SoilMaps = NULL,
OptionalClimateMaps = NULL,
CalibrateMode = NULL,
SmokeModelOutputs = NULL,
Write_SWA_Maps = NULL,
Write_CWD_Maps = NULL,
Write_Temperature_Maps = NULL,
Write_Species_Drought_Maps = NULL,
WaterDecayFunction = NULL,
ProbabilityEstablishAdjust = 1,
InitialMineralN = NULL,
InitialFineFuels = NULL,
AtmosphericNSlope = NULL,
AtmosphericNIntercept = NULL,
Latitude = NULL,
DenitrificationRate = NULL,
DecayRateSurf = NULL,
DecayRateSOM1 = NULL,
DecayRateSOM2 = NULL,
DecayRateSOM3 = NULL,
GrassThresholdMultiplier = NULL,
OutputMaps = NULL,
CreateInputCommunityMaps = NULL,
VariableOverrides = NULL,
SpeciesParameters = NULL,
DroughtMortalityParameters = NULL,
FireReductionParameters = NULL,
HarvestReductionParameters = NULL
)Arguments
pathCharacter. Directory path.
TimestepInteger.
SeedingAlgorithmCharacter. Dispersal algorithm to use. One of
"WardSeedDispersal","NoDispersal","UniversalDispersal".InitialCommunitiesCSVCharacter. Relative file path to the initial communities CSV (see 4 of the user guide).
InitialCommunitiesMapCharacter. Relative file path to the initial communities raster.
ClimateConfigFileCharacter. Relative file path to the climate library configuration file.
SoilMapsNamed list of relative file paths for required soil physical and initial soil organic matter / dead wood map inputs. Keys must match the NECN keywords (Tables 1 and 2 of the user guide):
SoilDepthMapName,SoilDrainMapName,SoilBaseFlowMapName,SoilStormFlowMapName,SoilFieldCapacityMapName,SoilWiltingPointMapName,SoilPercentSandMapName,SoilPercentClayMapName,InitialSOM1CsurfMapName,InitialSOM1NsurfMapName,InitialSOM1CsoilMapName,InitialSOM1NsoilMapName,InitialSOM2CMapName,InitialSOM2NMapName,InitialSOM3CMapName,InitialSOM3NMapName,InitialDeadWoodSurfaceMapName,InitialDeadCoarseRootsMapName.OptionalClimateMaps(Optional) Named list of relative file paths for any of
SlopeMapName,AspectMapName,NormalSWAMapName,NormalCWDMapName,NormalTempMapName.CalibrateModeLogical, or character indicating "yes" or "no".
SmokeModelOutputsLogical, or character indicating "yes" or "no".
Write_SWA_MapsLogical, or character indicating "yes" or "no".
Write_CWD_MapsLogical, or character indicating "yes" or "no".
Write_Temperature_MapsLogical, or character indicating "yes" or "no".
Write_Species_Drought_MapsLogical, or character indicating "yes" or "no".
WaterDecayFunctionCharacter. One of
"Linear"or"Ratio".ProbabilityEstablishAdjustNumeric. Multiplier applied to the probability of establishment. Default
1.0.InitialMineralNNumeric. Initial mineral N ($g/m^2$).
InitialFineFuelsNumeric in
[0, 1]. Fraction of initial dead wood allocated to fine fuels.AtmosphericNSlopeNumeric. Slope for linear N-deposition model.
AtmosphericNInterceptNumeric. Intercept for linear N-deposition model.
LatitudeNumeric. Study-site latitude (degrees).
DenitrificationRateNumeric in
[0, 1]. Monthly fraction of mineral N lost through ammonia volatilization and denitrification.DecayRateSurfNumeric in
[0, 1]. Max decay rate of SOM1-surface pool.DecayRateSOM1Numeric in
[0, 1]. Max decay rate of SOM1-soil pool.DecayRateSOM2Numeric in
[0, 1]. Max decay rate of SOM2 (slow) pool.DecayRateSOM3Numeric in
[0, 1]. Max decay rate of SOM3 (passive) pool.GrassThresholdMultiplier(Optional) Numeric. Grass/tree competition multiplier; see user guide 2.28.
OutputMaps(Optional) Named list of optional output-map keywords and values. See table 3 of the user guide. Allowed names:
ANPPMapName,ANPPMapFrequency,ANEEMapName,ANEEMapFrequency,SoilCarbonMapName,SoilNitrogenMapName,TotalCMapName.*MapNamevalues are file-name templates and must contain the literal{timestep}placeholder (user guide 2.29), e.g."NECN/ANPP-{timestep}.tif".CreateInputCommunityMapsLogical, or character indicating "yes" or "no".
VariableOverrides(Optional) Named list of numeric override values. Allowed names:
Stormflow,WaterFactor1,WaterFactor2,AnaerobicFactor1,AnaerobicFactor2,AnaerobicFactor3.SpeciesParametersCharacter. Relative file path to the species-parameters CSV (see 2.32, Table 4, of the user guide).
DroughtMortalityParameters(Optional) Character. Relative file path to the drought-mortality-parameters CSV (see 2.33, Table 5, of the user guide).
FireReductionParametersdata.framewith columnsFireSeverity,CoarseDebrisReduction,FineLitterReduction,CohortWoodReduction,CohortLeafReduction,SOMReduction. Required even when no fire extension is used.HarvestReductionParameters(Optional)
data.framewith columnsPrescriptionName,DeadWoodReduction,DeadLitterReduction,CohortWoodRemoval,CohortLeafRemoval.