Biomass Reclassification Output Extension
OutputBiomassReclass.RdBiomass Reclassification Output Extension
References
LANDIS-II Output Biomass Reclassification v4 Extension User Guide https://github.com/LANDIS-II-Foundation/Extension-Output-Biomass-Reclass/blob/master/docs/LANDIS-II%20Biomass%20Reclass%20Output%20v4%20User%20Guide.pdf
See also
Other Biomass Reclass Output helpers:
insertReclassMaps()
Super class
LandisExtension -> OutputBiomassReclass
Active bindings
ReclassMapsNested named list. See
$initialize()for the expected structure.MapFileNamesCharacter. Output filename pattern; must contain
{reclass-map-name}and{timestep}.
Methods
Inherited methods
OutputBiomassReclass$new()
Usage
OutputBiomassReclass$new(
path = NULL,
Timestep = 10L,
ReclassMaps = NULL,
MapFileNames = NULL
)Arguments
pathCharacter. Directory path.
TimestepInteger.
ReclassMapsNested named list. Top-level names are reclassification map names (no spaces). Each element is itself a named list whose names are forest types and whose values are character vectors of species codes. Species prefixed with
-are subtracted from the forest type's dominance value. See user guide 2.3.MapFileNamesCharacter. Output-map filename pattern; must contain the literals
{reclass-map-name}and{timestep}.