Construct a cohort selector for a Land Use Plus change block
cohortSelector.RdBundles a species code with one or more (low, high, percent) age-range
selections. Multiple ranges may be passed for the same species.
See also
Other Land Use Plus helpers:
LandUsePlus,
insertCohortSelector(),
insertLandCoverChange(),
insertLandUseType(),
landCoverChange(),
landUseType()
Examples
cohortSelector(
species = "querrubr",
ranges = data.frame(low = c(1, 71), high = c(62, 200), percent = c(20, 25))
)
#> $species
#> [1] "querrubr"
#>
#> $ranges
#> low high percent
#> 1 1 62 20
#> 2 71 200 25
#>
#> attr(,"class")
#> [1] "CohortSelector"