Construct a Biomass Harvest prescription
harvestPrescription.RdReturns a validated prescription specification. One or more of these is passed
to BiomassHarvest via Prescriptions.
Usage
harvestPrescription(
name,
StandRanking = NULL,
EconomicRankTable = NULL,
FireHazardTable = NULL,
TimeSinceLastFire = NULL,
TimeSinceLastWind = NULL,
MinimumAge = NULL,
MaximumAge = NULL,
StandAdjacency = NULL,
AdjacencyType = NULL,
AdjacencyNeighborSetAside = NULL,
MinimumTimeSinceLastHarvest = NULL,
ForestTypeTable = NULL,
PresalvageYears = NULL,
SiteSelection = NULL,
MinTargetSize = NULL,
MaxTargetSize = NULL,
PatchPercentage = NULL,
PatchSize = NULL,
AllowOverlap = NULL,
RepeatExactCells = NULL,
MinTimeSinceDamage = NULL,
PreventEstablishment = FALSE,
CohortsRemoved = NULL,
SpeciesList = NULL,
Plant = NULL,
SingleRepeat = NULL,
SingleRepeatCohortsRemoved = NULL,
SingleRepeatSpeciesList = NULL,
SingleRepeatPlant = NULL,
MultipleRepeat = NULL,
TimesToRepeat = NULL
)Arguments
- name
Character. Prescription name (no spaces); referenced from
HarvestImplementations.- StandRanking
Character. One of
"Economic","MaxCohortAge","RegulateAges","Random","FireHazard", or"TimeSinceDisturbance".- EconomicRankTable
data.framewith columnsSpecies,EconomicRank,MinimumAge. Required whenStandRanking = "Economic".- FireHazardTable
data.framewith columnsFuelType,FuelTypeRank. Required whenStandRanking = "FireHazard".- TimeSinceLastFire, TimeSinceLastWind
Integer. Years. Exactly one is required when
StandRanking = "TimeSinceDisturbance".- MinimumAge, MaximumAge
(Optional) Integer years.
- StandAdjacency
(Optional) Integer. Years.
- AdjacencyType
(Optional) Character. One of
"StandAge"or"TimeSinceLastHarvested".- AdjacencyNeighborSetAside
(Optional) Integer. Years.
- MinimumTimeSinceLastHarvest
(Optional) Integer. Years.
- ForestTypeTable
(Optional)
data.framewith columnsInclusionRule,AgeRange,PercentCells,Species. Multiple species may be space-separated in theSpeciescolumn.- PresalvageYears
(Optional) Integer. Years.
- SiteSelection
Character. One of
"Complete","CompleteStandSpread","PartialStandSpread", or"PatchCutting".- MinTargetSize, MaxTargetSize
Numeric (hectares). Required when
SiteSelectionis"CompleteStandSpread"or"PartialStandSpread".- PatchPercentage
Numeric in (0, 100]. Required when
SiteSelection = "PatchCutting".- PatchSize
Numeric (hectares). Required when
SiteSelection = "PatchCutting".- AllowOverlap, RepeatExactCells
(Optional) Logical. Only applies to
SiteSelection = "PatchCutting".- MinTimeSinceDamage
(Optional) Integer.
- PreventEstablishment
Logical. If
TRUE, emits the barePreventEstablishmentkeyword.- CohortsRemoved
Character. One of
"ClearCut","PlantOnly", or"SpeciesList".- SpeciesList
data.framewith columnsSpeciesandCohorts. Required whenCohortsRemoved = "SpeciesList".- Plant
(Optional) Character vector of species codes to plant after harvest.
- SingleRepeat
(Optional) Integer. Interval (years) for a single-repeat harvest.
- SingleRepeatCohortsRemoved
(Optional) Character.
CohortsRemovedmethod to use for the repeat entry; required whenSingleRepeatis set.- SingleRepeatSpeciesList
(Optional)
data.framelikeSpeciesList, used whenSingleRepeatCohortsRemoved = "SpeciesList".- SingleRepeatPlant
(Optional) Character vector of species to plant on the repeat entry.
- MultipleRepeat
(Optional) Integer. Interval (years) for a multiple-repeat harvest.
- TimesToRepeat
(Optional) Integer. Caps the number of multiple-repeat iterations.
See also
Other Biomass Harvest helpers:
BiomassHarvest,
insertCohortsRemoved(),
insertEconomicRankTable(),
insertFireHazardTable(),
insertForestTypeTable(),
insertHarvestImplementations(),
insertMultipleRepeat(),
insertPlant(),
insertPrescription(),
insertSingleRepeat(),
insertSiteSelection(),
insertStandRanking()