Skip to contents

Specify Dynamic Fire Extension FuelTypeTable

Usage

insertFuelTypeTable(df = NULL)

Arguments

df

data.frame specifying the rate of spread parameters for each base surface type, following the Canadian Forest Fire Behavior Prediction System (Forestry Canada, 1992). See defaultFuelTypeTable().

Value

Character string(s) to write to the suitable LANDIS-II input file.