Specify Dynamic Fire Extension FuelTypeTable
insertFuelTypeTable.RdSpecify Dynamic Fire Extension FuelTypeTable
Arguments
- df
data.framespecifying the rate of spread parameters for each base surface type, following the Canadian Forest Fire Behavior Prediction System (Forestry Canada, 1992). SeedefaultFuelTypeTable().