Prepare PnET-Succession Disturbance Reductions file
prepPnETDisturbanceReductions.RdWrites the disturbance reductions file (10 of the user guide),
which specifies how each disturbance partitions biomass into / out of the
dead pools. Rows correspond to the five reductions in
.pnetDisturbancePools; remaining columns are the disturbance types
active in the scenario (e.g. fire, wind, harvest, bda).
Arguments
- df
data.framewhose first column isPool(with values in .pnetDisturbancePools) and whose remaining columns are disturbance types. UsedefaultPnETDisturbanceReductions()for a starting point. Reduction values must be in[0, 1].- path
Character. Path specifying a directory to use for the scenario runs.
- filename
Character, specifying a filename (will be appended to
path).
Value
Character string(s) specifying suitable LANDIS-II input file(s), created as a side effect of the function.