Prepare PnET-Succession Generic Parameters file
prepPnETGenericParameters.RdWrites a PnETGenericParameters-format text file (7 of the
user guide). Any parameter omitted falls back to the defaults provided in
PnETGenericDefaultParameters.txt shipped with the extension. Allowed
parameter names: MaxCanopyLayers, LayerThreshRatio, PARunits, IMAX, DVPD1, DVPD2, BFolResp, MaintResp, TOroot, TOwood, Q10, FolLignin, KWdLit, InitialNSC, CFracBiomass, PrecipEvents, PrecipEventsWithReplacement, ETExtCoeff, RETCropCoeff, PreventEstablishment, Wythers, DTEMP, MaxPest, AmaxFrac, InvertPest, SoilIceDepth, LeakageFrostDepth, FrostFactor, InitialCommunitiesSpinup, SpinupWaterStress, Parallel, CohortStacking, CanopySumScale, CO2HalfSatEff.
Arguments
- params
Named list (or two-column
data.framewith columnsnameandvalue) of generic-parameter settings. Names must be drawn from the allowed parameter list above. Boolean values are coerced viayesno().- path
Character. Path specifying a directory to use for the scenario runs.
- filename
Character, specifying a filename (will be appended to
path).
Value
Character string(s) specifying suitable LANDIS-II input file(s), created as a side effect of the function.