Create LANDIS-II scenario files
scenario.RdCreate LANDIS-II scenario files
Arguments
- name
Character. Label to use as a filename and label for this scenario.
- extensions
List of LandisExtension objects.
- climate_config
LandisClimateConfig object.
- path
Character. Path specifying a directory to use for the scenario runs.
- ...
Arguments passed to other functions:
CellLengthNumeric. Size of ecoregion raster cells (in $m$);DisturbancesRandomOrderLogical. Should disturbances be applied in a random order?DurationNumeric. Number of years to run the simulation;EcoregionsFilesList of length 2 containing character file paths;RandomNumberSeedInteger. Seed used to initialize the LANDIS-II random number generator;SpeciesInputFileCharacter. Path to input file;